@@ -26,7 +26,7 @@ typedef struct SilcServerBackupStruct *SilcServerBackup;
 
 /* Callback function that is called after the key exchange and connection
    authentication protocols has been completed with a remote router. The
-   `server_entry' is the remote router entry. */
+   `server_entry' is the remote router entry or NULL on error. */
 typedef void (*SilcServerConnectRouterCallback)(SilcServer server,
 						SilcServerEntry server_entry,
 						void *context);
@@ -60,7 +60,7 @@ typedef struct {
 /* General definitions */
 
 /* SILC port */
-#define SILC_PORT 768;
+#define SILC_PORT 706;
 
 /* Server and router. Used internally by the code. */
 #define SILC_SERVER 0
@@ -98,7 +98,16 @@ do {								\
   silc_server_send_notify(server, sock, FALSE, 			\
 			  type, 1, __fmt__, strlen(__fmt__));	\
   silc_free(__fmt__);						\
-} while(0);
+} while(0)
+
+/* Send notify to operators */
+#define SILC_SERVER_SEND_OPERS(server, route, local, type, fmt)		\
+do {									\
+  char *__fmt__ = silc_format fmt;					\
+  silc_server_send_opers_notify(server, route, local,			\
+			        type, 1, __fmt__, strlen(__fmt__));	\
+  silc_free(__fmt__);							\
+} while(0)
 
 /* Check whether rekey protocol is active */
 #define SILC_SERVER_IS_REKEY(sock)					\
